@@ -3,11 +3,13 @@ use Moose;
 use MooseX::NonMoose;
 extends 'Atompub::Server';
 
+use AtomMQ::Schema;
 use Data::Dumper;
-use DBI;
 use XML::Atom;
 $XML::Atom::DefaultVersion = '1.0';
 
+our $VERSION = 0.0100;# VERSION
+
 has feed => (
     is => 'ro',
     isa => 'Str',
@@ -18,7 +20,7 @@ has dsn => (
     isa => 'Str',
     required => 1,
 );
-has username => (
+has user => (
     is => 'ro',
     isa => 'Str',
 );
@@ -26,45 +28,20 @@ has password => (
     is => 'ro',
     isa => 'Str',
 );
-has dbh => (
+has schema => (
     is => 'ro',
-    isa => 'DBI::db',
+    isa => 'AtomMQ::Schema',
     lazy => 1,
     default => sub {
         my $self = shift;
-        DBI->connect($self->dsn, $self->username, $self->password,
+        AtomMQ::Schema->connect($self->dsn, $self->user, $self->password,
             { RaiseError => 1, AutoCommit => 1 });
     }
 );
 
-my $ENTRY_TABLE = 'atommq_entry';
-#$ENTRY_TABLE = 'foo';
-
 sub BUILD {
     my $self = shift;
-    my $dsn = $self->dsn;
-
-    my $db_type = (split /:/, $self->dsn)[1];
-    die "invalid dsn [$dsn]" unless $db_type;
-    $db_type = lc $db_type;
-
-    my %auto_inc = (
-        sqlite => 'AUTOINCREMENT',
-        mysql  => 'AUTO_INCREMENT',
-    );
-    my $auto_inc = $auto_inc{$db_type};
-    die "The database $db_type is not supported. Currently, the only supported"
-        . " databases are [ @{[join ', ', keys %auto_inc]} ]"
-        unless $auto_inc;
-
-    $self->dbh->do(qq{
-        CREATE TABLE IF NOT EXISTS $ENTRY_TABLE (
-            id INTEGER PRIMARY KEY $auto_inc,
-            feed VARCHAR(255) NOT NULL,
-            title VARCHAR(255) NOT NULL,
-            content TEXT NOT NULL
-        )
-    });
+    $self->schema->deploy;
 }
 
 my %dispatch = (
@@ -84,33 +61,33 @@ sub handle_request {
 
 sub get_feed {
     my $self = shift;
-    my $dbh = $self->dbh;
     my $feed_name = $self->feed;
     #my $p = $self->request_param('start-index');
     my $last_id = $self->request_header('Xlastid') || 0;
     my $feed = XML::Atom::Feed->new;
     $feed->title($feed_name);
-    my $sql = "select * from $ENTRY_TABLE where feed = ? and id > ?";
-    my $rows = $dbh->selectall_arrayref($sql, {Slice => {}},
-        $feed_name, $last_id);
-    for my $row (@$rows) {
+    my $rset = $self->schema->resultset('AtomMQEntry')->search({
+        id   => { '>' => $last_id },
+        feed => $feed_name,
+    });
+    while (my $row = $rset->next) {
         my $entry = XML::Atom::Entry->new;
-        $entry->title($row->{title});
-        $entry->content($row->{content});
-        $entry->id($row->{id});
+        $entry->title($row->title);
+        $entry->content($row->content);
+        $entry->id($row->id);
         $feed->add_entry($entry);
     }
-
     return $feed->as_xml;
 }
 
 sub new_post {
     my $self = shift;
-    my $dbh = $self->dbh;
     my $entry = $self->atom_body or return;
-    $dbh->do("insert into $ENTRY_TABLE (feed, title, content) values (?,?,?)",
-        {}, $self->feed, $entry->title, $entry->content->body);
-    #return Dumper $dbh->selectall_arrayref("select * from $ENTRY_TABLE");
+    $self->schema->resultset('AtomMQEntry')->create({
+        feed    => $self->feed,
+        title   => $entry->title,
+        content => $entry->content->body,
+    });
 }
 
 # ABSTRACT: An atompub server that supports the message queue/bus model.
@@ -127,7 +104,7 @@ AtomMQ - An atompub server that supports the message queue/bus model.
 
 =head1 VERSION
 
-version 0.0001
+version 0.0100
 
 =head1 SYNOPSIS
 
@@ -159,6 +136,7 @@ run via mod_perl on apache, but that is more complicated.  To create more
 feeds, just copy that file and change 'MyCoolFeed' to 'MyOtherFeed'.
 
 To publish a message to AtomMQ, make a HTTP POST request:
+
     $ curl -d '<entry> <title>allo</title> <content type="xhtml">
       <div xmlns="http://www.w3.org/1999/xhtml" >an important message</div>
       </content> </entry>' http://localhost/cgi-bin/mycoolfeed
